translate.storage.placeables.interfaces

Package translate :: Package storage :: Package placeables :: Module interfaces |
[hide private]
[frames] | no frames]

# Source Code for Module translate.storage.placeables.interfaces

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2009 Zuza Software Foundation
     5  #
     6  # This file is part of the Translate Toolkit.
     7  #
     8  # This program is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # This program is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with this program; if not, see <http://www.gnu.org/licenses/>.
    20
    21  """
    22  This file contains abstract (semantic) interfaces for placeable implementations.
    23  """
    24
    25  from translate.storage.placeables.strelem import StringElem
    26
    27
    28 -class InvisiblePlaceable(StringElem):
    29      parse = None
    30
    31
    32 -class MaskingPlaceable(StringElem):
    33      parse = None
    34
    35
    36 -class ReplacementPlaceable(StringElem):
    37      parse = None
    38
    39
    40 -class SubflowPlaceable(StringElem):
    41      parse = None
    42
    43
    44 -class Delimiter(object):
    45      pass
    46
    47
    48 -class PairedDelimiter(object):
    49      pass
    50